| Title: | Neuroblastoma Copy Number Profiles |
|---|---|
| Description: | Annotated neuroblastoma copy number profiles, a benchmark data set for change-point detection algorithms, as described by Hocking et al. <doi:10.1186/1471-2105-14-164>. |
| Authors: | Toby Dylan Hocking [aut, cre] |
| Maintainer: | Toby Dylan Hocking <[email protected]> |
| License: | GPL-3 |
| Version: | 2023.9.3 |
| Built: | 2026-05-08 06:58:32 UTC |
| Source: | https://github.com/tdhock/neuroblastoma |
Tumors from patients at the Institut Curie were assayed using array
comparative genomic hybridization.
Their normalized copy number profiles are available
as neuroblastoma$profiles and the breakpoint annotations are available
as neuroblastoma$annotations.
data(neuroblastoma)data(neuroblastoma)
A named list of 2 data frames:
profilesA data.frame with one row for each probe, and these variables:
profile.idfactor: id of copy number profile.
chromosomefactor: chromosome on which the probe was mapped.
positioninteger: probe was mapped to this position in base pairs.
logrationumeric: normalized logratio of the probe, which should be proportional to copy number.
annotationsa data.frame with one row for each annotated region, and these variables:
profile.idfactor: id of copy number profile.
chromosomefactor: chromosome of this annotation.
mininteger: lower limit of this region in base pairs.
maxinteger: upper limit of this region in base pairs.
annotationfactor: annotation of this region,
either "normal" for no breakpoints or
"breakpoint"
for at least one breakpoint.
Gudrun Schleiermacher and Isabelle Janoueix-Lerosey, Institut Curie.